@@ -5,7 +5,6 @@ OC.L10N.register(
     "Rename" : "Renomar",
     "Copy link" : "Copiar l'enllaz",
     "Move" : "Mover",
-    "Delete" : "Desaniciar",
     "Link copied to clipboard" : "L'enllaz copióse nel cartafueyu",
     "Delete selection" : "Desaniciar la seleición",
     "Select all" : "Seleicionar too",
@@ -15,14 +14,15 @@ OC.L10N.register(
     "Search" : "Buscar",
     "_%n folder_::_%n folders_" : ["%n carpeta","%n folders"],
     "Rename folder" : "Renomar la carpeta",
-    "Delete folder" : "Desaniciar la carpeta",
     "Submit" : "Unviar",
     "Cancel" : "Encaboxar",
     "Recent" : "De recién",
     "Shared with you" : "Compartióse contigo",
     "Files" : "Ficheros",
+    "Delete" : "Desaniciar",
     "Settings" : "Configuración",
     "Bookmarklet" : "Bookmarklet",
+    "Need help?" : "¿Precises ayuda?",
     "Title" : "Tñitulu",
     "Link" : "Enllaz",
     "Tags" : "Etiquetes",
