@@ -37,7 +37,6 @@ OC.L10N.register(
     "Bookmark updated" : "Ο σελιδοδείκτης ενημερώθηκε",
     "Create bookmark" : "Δημιουργία σελιδοδείκτη",
     "Takes a link and adds it to your collection of bookmarks." : "Αυτή η ενέργεια, παίρνει έναν σύνδεσμο και τον προσθέτει στη συλλογή των σελιδοδεικτών σας.",
-    "A Bookmark manager for Nextcloud" : "Διαχειριστής σελιδοδεικτών του Nextcloud",
     "Enter new title" : "Εισάγετε νέο τίτλο",
     "Select bookmark" : "Επιλογή σελιδοδείκτη",
     "Details" : "Λεπτομέρειες",
@@ -144,21 +143,19 @@ OC.L10N.register(
     "Remove share" : "Κατάργηση διαμοιρασμού",
     "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
     "Privacy" : "Ιδιωτικότητα",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Οι σελιδοδείκτες θα προσπαθήσουν να έχουν πρόσβαση στις ιστοσελίδες που προσθέτετε για την αυτόματη πληροφόρησή σας.",
     "Enable accessing and collecting information from the web pages you add" : "Ενεργοποιήστε την πρόσβαση και συλλογή πληροφοριών των ιστοσελίδων που προσθέτετε",
     "Performance" : "Απόδοση",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Σε μια εγκατάσταση με πολλούς χρήστες μπορεί να είναι χρήσιμο να περιοριστεί ο αριθμός των σελιδοδεικτών ανά λογαριασμό.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Μέγιστος επιτρεπόμενος αριθμός σελιδοδεικτών ανά λογαριασμό. (0 χωρίς όριο; η προεπιλογή δεν έχει όριο)",
     "Previews" : "Προεπισκοπήσεις",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Προκειμένου να προβάλλονται τα πραγματικά στιγμιότυπα οθόνης των ιστοσελίδων που προσθέτετε στους σελιδοδείκτες, η εφαρμογή Bookmarks μπορεί να χρησιμοποιήσει μια υπηρεσία τρίτου μέρους, για τη δημιουργία προεπισκόπησης.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Μπορείτε να εγγραφείτε δωρεάν στο screeenly.com είτε να ρυθμίσετε το δικό σας διακομιστή.",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Κλειδί Screeenly API",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "Webshot API URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API key",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "Webshot API URL",
     "Pageres CLI" : "Pageres CLI",
     "Failed to save settings" : "Αποτυχία αποθήκευσης ρυθμίσεων",
     "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
