@@ -4,7 +4,6 @@ OC.L10N.register(
     "Bookmarks" : "Legosignaro",
     "No file provided for import" : "Neniu dosiero provizita por enporto",
     "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
-    "A Bookmark manager for Nextcloud" : "Mastrumilo de legosignoj por Nextcloud",
     "Select bookmark" : "Elekti legosignon",
     "Details" : "Detaloj",
     "Rename" : "Alinomi",
@@ -55,7 +54,6 @@ OC.L10N.register(
     "Allow resharing" : "Permesi rekunhavigon",
     "Link copied" : "Ligilo kopiita",
     "Privacy" : "Privateco",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "„Legosignaro“ provos aliri retpaĝojn, kiujn vi aldonas por aldoni aŭtomate informojn pri ili.",
     "Enable accessing and collecting information from the web pages you add" : "Ebligi aliron al kaj kolekton de informoj el la retpaĝoj, kiujn vi aldonas",
     "Performance" : "Rendimento",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
