@@ -5,22 +5,22 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Copy link" : "Copiar enlace",
     "Move" : "Mover",
-    "Delete" : "Eliminar",
     "Select all" : "Seleccionar todo",
     "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
     "Search" : "Buscar",
     "Rename folder" : "Renombrar carpeta",
-    "Delete folder" : "Borrar carpeta",
     "Choose folder" : "Elegir carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
     "Shared with you" : "Compartido con usted",
     "Files" : "Archivos",
+    "Delete" : "Eliminar",
     "Settings" : "Ajustes",
     "Bookmarklet" : "Marcador a código",
+    "Need help?" : "¿Necesita ayuda?",
     "Title" : "Título",
     "Link" : "Link",
     "Tags" : "Etiquetas",
