@@ -5,21 +5,21 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Copy link" : "Copiar liga",
     "Move" : "Mover",
-    "Delete" : "Borrar",
     "Select all" : "Seleccionar todo",
     "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
     "Search" : "Buscar",
-    "Delete folder" : "Borrar carpeta",
     "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
     "Shared with you" : "Compartido con usted",
     "Files" : "Archivos",
+    "Delete" : "Borrar",
     "Settings" : "Ajustes",
     "Bookmarklet" : "Marcador a código",
+    "Need help?" : "¿Necesitas ayuda?",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
