@@ -5,7 +5,6 @@ OC.L10N.register(
     "Rename" : "Nimeta ümber",
     "Copy link" : "Kopeeri link",
     "Move" : "Liiguta",
-    "Delete" : "Kustuta",
     "Delete selection" : "Kustuta valik",
     "Select all" : "Vali kõik",
     "Go back" : "Mine tagasi",
@@ -13,14 +12,15 @@ OC.L10N.register(
     "New folder" : "Uus kaust",
     "Search" : "Otsi",
     "Rename folder" : "Nimeta kaust ümber",
-    "Delete folder" : "Kustuta kaust",
     "Choose folder" : "Vali kaust",
     "Submit" : "Saada",
     "Cancel" : "Loobu",
     "Recent" : "Hiljutised",
     "Shared with you" : "Sinuga jagatud",
     "Files" : "Failid",
+    "Delete" : "Kustuta",
     "Settings" : "Seaded",
+    "Need help?" : "Vajad abi?",
     "Title" : "Pealkiri",
     "Link" : "Link",
     "Tags" : "Sildid",
