@@ -38,7 +38,6 @@ OC.L10N.register(
     "Create bookmark" : "Luo kirjanmerkki",
     "Takes a link and adds it to your collection of bookmarks." : "Poimii linkin ja lisää sen kirjanmerkkikokoelmaasi",
     "Bookmarks Backups" : "Kirjanmerkkien varmuuskopiot",
-    "A Bookmark manager for Nextcloud" : "Kirjanmerkkien hallinta Nextcloudille",
     "Enter new title" : "Syötä uusi nimi",
     "Select bookmark" : "Valitse kirjanmerkki",
     "Details" : "Tiedot",
@@ -182,21 +181,19 @@ OC.L10N.register(
     "Remove share" : "Poista jako",
     "Link copied" : "Linkki kopioitu",
     "Privacy" : "Yksityisyys",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Kirjanmerkkisovellus voi hakea lisätietoa sivuilta, jotka lisäät kirjanmerkkeihin.",
     "Enable accessing and collecting information from the web pages you add" : "Ota käyttöön tiedonhaku kirjanmerkiksi lisätyiltä verkkosivuilta",
     "Performance" : "Suorituskyky",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Tilikohtaisten kirjanmerkkien määrää voi olla hyödyllistä rajoittaa usean käyttäjän kokoonpanoissa.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Käyttäjätilikohtaisten kirjanmerkkien enimmäismäärä. (0 tarkoittaa ei rajoitusta; oletus on ei rajoitusta)",
     "Previews" : "Esikatselut",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Näyttääksesi esikatselut kirjamerkeiksi lisätyiltä verkkosivuilta, kirjanmerkkisovellus voi käyttää kolmannen osapuolen palveluita esikatseluiden luomiseen.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Voit rekisteröityä veloituksetta osoitteessa screeenly.com tai pystyttää oman palvelimen.",
     "Screeenly API URL" : "Screeenly-palvelun API:n URL",
     "Screeenly API key" : "Screeenly-palvelun API-avain",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "Webshotin API:n URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachinen API-avain",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "Webshotin API:n URL",
     "Pageres CLI" : "Pageres CLI",
     "Pageres ENV variables" : "Pageresin ENV-muuttujat",
     "Failed to save settings" : "Asetusten tallentaminen epäonnistui",
