@@ -25,7 +25,6 @@ OC.L10N.register(
     "Bookmark updated" : "סימנייה עודכנה",
     "Create bookmark" : "יצירת סימנייה",
     "Takes a link and adds it to your collection of bookmarks." : "לוקח קישור ומוסיף אותו לאוסף הסימניות שלך.",
-    "A Bookmark manager for Nextcloud" : "מנהל סימניות ל־Nextcloud",
     "Enter new title" : "נא למלא כותרת חדשה",
     "Select bookmark" : "בחירת סימנייה",
     "Details" : "פרטים",
@@ -105,7 +104,6 @@ OC.L10N.register(
     "Remove share" : "הסרת שיתוף",
     "Link copied" : "הקישור הועתק",
     "Privacy" : "פרטיות",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
     "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
     "Performance" : "ביצועים",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "כמות הסימניות המרבית לחשבון. (0 ללא הגבלה וזאת גם בררת המחדל)",
