@@ -37,7 +37,6 @@ OC.L10N.register(
     "Bookmark updated" : "Knjižna oznaka je ažurirana",
     "Create bookmark" : "Stvori knjižnu oznaku",
     "Takes a link and adds it to your collection of bookmarks." : "Dodaje poveznicu u zbirku knjižnih oznaka.",
-    "A Bookmark manager for Nextcloud" : "Upravitelj knjižnim oznakama za Nextcloud",
     "Enter new title" : "Unesi novi naslov",
     "Select bookmark" : "Odaberi knjižnu oznaku",
     "Details" : "Pojedinosti",
@@ -157,21 +156,19 @@ OC.L10N.register(
     "Remove share" : "Ukloni dijeljenje",
     "Link copied" : "Poveznica je kopirana",
     "Privacy" : "Privatnost",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Knjižne oznake pokušat će pristupiti mrežnim mjestima koje dodate kako bi automatski dohvatilo više informacija o tim mrežnim mjestima.",
     "Enable accessing and collecting information from the web pages you add" : "Omogući pristup i prikupljanje informacija s dodanih mrežnih mjesta",
     "Performance" : "Učinkovitost",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Kod instalacija s većim brojem korisnika može biti korisno ograničiti broj knjižnih oznaka po računu.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Najveći dopušteni broj knjižnih oznaka po računu. (0 znači da nema ograničenja; zadano je bez ograničenja)",
     "Previews" : "Pretpregledi",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Kako bi se prikazale stvarne snimke zaslona označenih web-mjesta, Knjižne oznake mogu se koristiti servisima trećih strana za generiranje pretpregleda.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Besplatno se prijavite na screeenly.com ili postavite vlastiti poslužitelj.",
     "Screeenly API URL" : "URL Screeenly API-ja",
     "Screeenly API key" : "Ključ Screeenly API-ja",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "URL Webshot API-ja",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "Ključ ScreenshotMachine API-ja",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "URL Webshot API-ja",
     "Pageres CLI" : "Pageres CLI",
     "Failed to save settings" : "Spremanje postavki nije uspjelo",
     "Failed to load settings" : "Učitavanje postavki nije uspjelo",
