@@ -38,7 +38,6 @@ OC.L10N.register(
     "Create bookmark" : "Könyvjelző létrehozása",
     "Takes a link and adds it to your collection of bookmarks." : "Fog egy hivatkozást, és hozzáadja a könyvjelzők gyűjteményéhez.",
     "Bookmarks Backups" : "Könyvjelzők biztonsági mentése",
-    "A Bookmark manager for Nextcloud" : "Könyvjelzőkezelő a Nextcloudhoz",
     "Enter new title" : "Adja meg a címet",
     "Select bookmark" : "Válasszon könyvjelzőt",
     "Details" : "Részletek",
@@ -173,23 +172,20 @@ OC.L10N.register(
     "Remove share" : "Megosztás eltávolítása",
     "Link copied" : "Hivatkozás másolva",
     "Privacy" : "Adatvédelem",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "A könyvjelzők megpróbálnak hozzáférni a hozzáadott weboldalakhoz, hogy automatikusan hozzáadják a rájuk vonatkozó információkat.",
     "Enable accessing and collecting information from the web pages you add" : "Engedélyezze az információk elérését és összegyűjtését a hozzáadott weboldalakról",
     "Performance" : "Teljesítmény",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "S sok felhasználót tartalmazó példányokon célszerű a fiókonkénti könyvjelzők számát korlátozni.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "A fiókonként maximálisan engedélyezett könyvjelzők száma. (0: nincs korlátozás, ez az alapértelmezés)",
     "Previews" : "Előnézetek",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Ahhoz, hogy valódi képernyőképeket kapjon a könyvjelzőzött weboldalakról, a Könyvjelzőknek szüksége van egy harmadik fél által üzemeltetett szolgáltatásra, amely előállítja a képernyőképeket.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screeenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API-kulcs",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "Webshot API URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API-kulcs",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "Webshot API URL",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Csak telepítse a Pageres CLI-t a kiszolgálón, és a Könyvjelzők meg fogja találni. További környezeti változókat adhat meg a pageresnek, például ahogy a helykitöltő mutatja:",
     "Pageres ENV variables" : "Pageres környezeti változók",
     "Failed to save settings" : "A beállítások mentése sikertelen",
     "Failed to load settings" : "A beállítások betöltése sikertelen",
