@@ -5,7 +5,6 @@ OC.L10N.register(
     "No file provided for import" : "Engin skrá valin til innflutnings",
     "Unsupported file type for import" : "Ekki er hægt að flytja inn þessa tegund af bókamerki",
     "Bookmarks shared by %s" : "Bókamerki deilt af %s",
-    "A Bookmark manager for Nextcloud" : "Bókamerkjastjóri fyrir Nextcloud",
     "Select bookmark" : "Veldu bókamerki",
     "Details" : "Nánar",
     "Rename" : "Endurnefna",
@@ -72,7 +71,6 @@ OC.L10N.register(
     "Remove share" : "Fjarlægja sameign",
     "Link copied" : "Tengill afritaður",
     "Privacy" : "Gagnaleynd",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bókamerkjaforritið mun reyna að fá aðgang að þeim síðum sem þú bætir við til að sækja sjálfvirkt upplýsingar um þær.",
     "Enable accessing and collecting information from the web pages you add" : "Virkja aðgang og söfnun upplýsinga af vefsíðunum sem þú bætir við",
     "Performance" : "Afköst",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Leyfður hámarksföldi bókamerkja á hvern notandaaðgang. (0 fyrir engin takmörk; það er sjálfgefið)",
