@@ -5,21 +5,21 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Copy link" : "Copy link",
     "Move" : "Move",
-    "Delete" : "Delete",
     "Select all" : "Select all",
     "Go back" : "Go back",
     "New" : "New",
     "New folder" : "New folder",
     "Search" : "Search",
     "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
-    "Delete folder" : "Delete folder",
     "Submit" : "Submit",
     "Cancel" : "Cancel",
     "Recent" : "Recent",
     "Shared with you" : "Shared with you",
     "Files" : "ფაილები",
+    "Delete" : "Delete",
     "Settings" : "Settings",
     "Bookmarklet" : "Bookmarklet",
+    "Need help?" : "Need help?",
     "Link" : "Link",
     "Tags" : "Tags",
     "Notes" : "Notes",
