@@ -5,18 +5,18 @@ OC.L10N.register(
     "Rename" : "ປ່ຽນຊື່",
     "Copy link" : "ສຳເນົາລິງ",
     "Move" : "ຍ້າຍ",
-    "Delete" : "ລຶບ",
     "Select all" : "ເລືອກທັງໝົດ",
     "New folder" : "ໂຟນເດີໃຫມ່",
     "Search" : "ຄົ້ນຫາ",
     "Sort by created date" : "ຈັດລຽງຕາມລຳດັບວັນທີສ້າງ",
     "Rename folder" : "ປ່ຽນຊືໂຟນເດີ",
-    "Delete folder" : "ລຶບໂຟນເດີ",
     "Cancel" : "ຍົກເລີກ",
     "Recent" : "ຫວ່າງບໍ່ດົນມາ ນີ້",
     "Shared with you" : "ແບ່ງປັບກັບທ່ານ",
     "Files" : "ຟາຍ",
+    "Delete" : "ລຶບ",
     "Settings" : "ການຕັ້ງຄ່າ",
+    "Need help?" : "ຕ້ອງການຄວາມຊ່ວຍເຫຼືອ?",
     "Link" : "ລິງ",
     "Tags" : "ປ້າຍກຳກັບ",
     "Download file" : "ດາວ ໂຫລດຟາຍ",
