@@ -17,7 +17,6 @@ OC.L10N.register(
     "You shared folder \"%1$s\" with %2$s" : "Jūs pradėjote bendrinti aplanką „%1$s“ su %2$s",
     "No file provided for import" : "Importavimui nepateiktas joks failas",
     "Unsupported file type for import" : "Importavimui pateiktas nepalaikomas failo tipas",
-    "A Bookmark manager for Nextcloud" : "Adresyno tvarkytuvė, skirta Nextcloud",
     "Select bookmark" : "Pasirinkti adresyno įrašą",
     "Details" : "Išsamiau",
     "Rename" : "Pervadinti",
@@ -78,7 +77,6 @@ OC.L10N.register(
     "Remove share" : "Šalinti viešinį",
     "Link copied" : "Nuoroda nukopijuota",
     "Privacy" : "Privatumas",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adresynas bandys apsilankyti jūsų pridedamose internetinėse svetainėse, kad automatiškai pridėtų informaciją apie jas.",
     "Enable accessing and collecting information from the web pages you add" : "Leisti apsilankyti ir rinkti iš saityno informaciją apie jūsų pridedamus internetinius puslapius",
     "Performance" : "Našumas",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Didžiausias, vienai paskyrai leidžiamas, adresyno įrašų skaičius. (0, kad būtų neribojama; pagal numatymą yra neribojama)",
