@@ -5,7 +5,6 @@ OC.L10N.register(
     "Rename" : "Преименувај",
     "Copy link" : "Копирај линк",
     "Move" : "Премести",
-    "Delete" : "Избриши",
     "Delete selection" : "Избриши ги селектираните",
     "Select all" : "Избери се",
     "Go back" : "Назад",
@@ -15,13 +14,14 @@ OC.L10N.register(
     "Search" : "Барај",
     "RSS feed copied" : "RSS канал копиран",
     "Rename folder" : "Преименувај папка",
-    "Delete folder" : "Избриши папка",
     "Submit" : "Испрати",
     "Cancel" : "Откажи",
     "Recent" : "Неодамнешни",
     "Shared with you" : "Споделено со вас",
     "Files" : "Датотеки",
+    "Delete" : "Избриши",
     "Settings" : "Параметри",
+    "Need help?" : "Ви треба помош?",
     "Title" : "Наслов",
     "Link" : "Линк",
     "Tags" : "Ознаки",
