@@ -5,17 +5,17 @@ OC.L10N.register(
     "Rename" : "Gje nytt namn",
     "Copy link" : "Kopier lenkje",
     "Move" : "Move",
-    "Delete" : "Ta bort",
     "Select all" : "Merk alt",
     "New" : "Ny",
     "New folder" : "Ny mappe",
     "Search" : "Søk",
-    "Delete folder" : "Slett mappe",
     "Choose folder" : "Vel mappe",
     "Cancel" : "Avbryt",
     "Shared with you" : "Shared with you",
     "Files" : "Filer",
+    "Delete" : "Ta bort",
     "Settings" : "Innstillingar",
+    "Need help?" : "Treng du hjelp?",
     "Title" : "Tittel",
     "Link" : "Lenkje",
     "Tags" : "Emneord",
