@@ -5,7 +5,6 @@ OC.L10N.register(
     "Rename" : "Redenumire",
     "Copy link" : "Copiază link",
     "Move" : "Mută",
-    "Delete" : "Șterge",
     "Select all" : "Selectează tot",
     "Go back" : "Înapoi",
     "Share folder" : "Distribuie dosar",
@@ -13,13 +12,14 @@ OC.L10N.register(
     "New folder" : "Director nou",
     "Search" : "Caută",
     "Rename folder" : "Redenumește dosar",
-    "Delete folder" : "Șterge director",
     "Submit" : "Trimite",
     "Cancel" : "Anulează",
     "Recent" : "Recente",
     "Shared with you" : "Partajat cu tine",
     "Files" : "Fișiere",
+    "Delete" : "Șterge",
     "Settings" : "Setări",
+    "Need help?" : "Ai nevoie de ajutor?",
     "Title" : "Titlu",
     "Link" : "Legătură",
     "Root folder" : "Folder principal",
