@@ -37,7 +37,6 @@ OC.L10N.register(
     "Bookmark updated" : "Signalibru assignadu",
     "Create bookmark" : "Crea unu signalibru",
     "Takes a link and adds it to your collection of bookmarks." : "Pigat unu ligòngiu e dd'agiunghet a sa colletzione tua de signalibros.",
-    "A Bookmark manager for Nextcloud" : "Unu gestore de signalibru pro Nextcloud",
     "Enter new title" : "Inserta unu tìtulu nou",
     "Select bookmark" : "Seletziona signalibru",
     "Details" : "Detàllios",
@@ -150,21 +149,19 @@ OC.L10N.register(
     "Remove share" : "Boga cumpartzidura",
     "Link copied" : "Ligòngiu copiadu",
     "Privacy" : "Riservadesa",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Signalibros at a proare a intrare a is pàginas chi as agiuntu pro integrare informatziones subra de custas in automàticu.",
     "Enable accessing and collecting information from the web pages you add" : "Abilita s'atzessu a sa regollida de informatziones dae is pàginas internet chi agiùnghes",
     "Performance" : "Atuatzione",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "In un'installatzione cun ùtentes medas, diat pòdere torrare ùtile a minimare su nùmeru de signalibros pro cada contu.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Su nùmeru màssimu cunsentidu de signalibros pro cada contu. (0 pro illimitadu; predefinidu illimitadu)",
     "Previews" : "Anteprima",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Pro bìdere is ischermadas etotu de is sitos ìnternet preferidos tuos, Signalibros podet impreare unu servìtziu de àtere pro generare is anteprimas.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Ti podes registrare sena pagare in screeenly.com o cunfigurare su serbidore.",
     "Screeenly API URL" : "API URL de Screeenly ",
     "Screeenly API key" : "Crae API de Screeenly ",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : " API URL Webshot",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "Crae ScreenshotMachine API ",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : " API URL Webshot",
     "Pageres CLI" : "Pageres CLI",
     "Failed to save settings" : "No at fatu a sarvare is informatziones",
     "Failed to load settings" : "Impossìbile carrigare sa cunfiguratzione",
