@@ -38,7 +38,6 @@ OC.L10N.register(
     "Create bookmark" : "Ustvari zaznamek",
     "Takes a link and adds it to your collection of bookmarks." : "Prevzame povezavo in jo doda v zbirko zaznamkov.",
     "Bookmarks Backups" : "Varnostne kopije zaznamkov",
-    "A Bookmark manager for Nextcloud" : "Upravljalnik zaznamkov za Nextcloud",
     "Enter new title" : "Vpis novega naslova",
     "Select bookmark" : "Izbor zaznamka",
     "Details" : "Podrobnosti",
@@ -173,23 +172,20 @@ OC.L10N.register(
     "Remove share" : "Odstrani souporabo",
     "Link copied" : "Povezava je kopirana",
     "Privacy" : "Zasebnost",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Program poskuša pridobiti podatke dodanih spletnih strani in jih dodati v opis povezave.",
     "Enable accessing and collecting information from the web pages you add" : "Omogoči dostop in zbiranje podatkov z dodanih spletnih strani",
     "Performance" : "Delovanje",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Na sistemu z velikim številom uporabnikov je priporočeno omejiti število zaznamkov na račun",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Največje dovoljeno število zaznamkov na račun (privzeta vrednost je 0 – brez omejitve)",
     "Previews" : "Predogledi",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Za prikaz pravih zaslonskih slik zaznamkov spletnih strani, program uporablja storitve tretjih oseb za ustvarjanje predogledov.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Lahko se brezplačno vpišete na spletni strani screeenly.com, ali pa nastavite svoj strežnik.",
     "Screeenly API URL" : "Naslov URL vmesnika Screeenly API",
     "Screeenly API key" : "Ključ vmesnika Screeenly API",
-    "Webshot" : "Slika spletne strani",
-    "Webshot API URL" : "Slika spletne strani API URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "Ključ vmesnika API ScreenshotMachine",
+    "Webshot" : "Slika spletne strani",
+    "Webshot API URL" : "Slika spletne strani API URL",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Preprosto namestite vmesnik Pageres CLI v strežnik in zaznamki ga bodo našli. Še vedno lahko dodate dodatne spremenljivke ENV, ki se posredujejo programu, npr. kot je navedeno v vsebniku:",
     "Pageres ENV variables" : "Spremenljivke Pageres ENV",
     "Failed to save settings" : "Shranjevanje nastavitev je spodletelo",
     "Failed to load settings" : "Nalaganje nastavitev je spodletelo.",
