@@ -5,23 +5,23 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Copy link" : "Kopjo linkun",
     "Move" : "Zhvendos",
-    "Delete" : "Fshij",
     "Select all" : "Zgjidhi të gjitha",
     "Go back" : "Shko prapa",
     "New" : "I ri",
     "New folder" : "Dosje e re",
     "Search" : "Kërko",
     "Rename folder" : "Riemërtoni dosjen",
-    "Delete folder" : "Fshini dosjen",
     "Choose folder" : "Zgjidhni dosjen",
     "Submit" : "Dërgo",
     "Cancel" : "Anullo",
     "Recent" : "Së fundmi",
     "Shared with you" : "E ndarë me ju",
     "Files" : "Skedarët",
+    "Delete" : "Fshij",
     "Untagged" : "E paetiketuar",
     "Settings" : "Rregullimet",
     "Bookmarklet" : "Libër Shënues",
+    "Need help?" : "Ju duhet ndihmë?",
     "Title" : "Titulli",
     "Link" : "Lidhje",
     "Tags" : "Etiketat",
