@@ -38,9 +38,10 @@ OC.L10N.register(
     "Create bookmark" : "Skapa bokmärke",
     "Takes a link and adds it to your collection of bookmarks." : "Tar en länk och lägger till den i dina bokmärken.",
     "Bookmarks Backups" : "Bokmärken säkerhetskopior",
-    "A Bookmark manager for Nextcloud" : "En bokmärkeshanterare för Nextcloud",
     "Enter new title" : "Ange ny titel",
     "Select bookmark" : "Välj bokmärke",
+    "You have never clicked this link" : "Du har aldrig klickat på den här länken",
+    "You have clicked this link {count} times" : "Du har klickat på den här länken {count} gånger",
     "Details" : "Detaljer",
     "Rename" : "Byt namn",
     "Copy link" : "Kopiera länk",
@@ -51,7 +52,7 @@ OC.L10N.register(
     "Delete bookmark permanently" : "Ta bort bokmärke permanent",
     "Do you really want to delete this bookmark?" : "Är du säker att du vill ta bort detta bokmärket?",
     "Link copied to clipboard" : "Länken kopierad till urklipp",
-    "Content pending" : "Innehåll förestår",
+    "Content pending" : "Väntar på innehåll",
     "This content is being downloaded for offline use. Please check back later." : "Detta innehåll laddas ner för offlineanvändning. Vänligen försök igen senare.",
     "Bookmarked {time} ago" : "Sparad för {time} sedan",
     "Bookmarked on {date}" : "Sparad den {date}",
@@ -199,23 +200,26 @@ OC.L10N.register(
     "Remove share" : "Ta bort delning",
     "Link copied" : "Länk kopierad",
     "Privacy" : "Integritet",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bokmärken kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
+    "The app will try to access web pages that you add to automatically add information about them." : "Appen kommer försöka komma åt webbsidor som du lägger till för att automatiskt lägga till information om dem.",
     "Enable accessing and collecting information from the web pages you add" : "Aktivera åtkomst till och samla information från webbsidorna du lägger till",
     "Performance" : "Prestanda",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med många användare kan det vara nödvändigt att begränsa antalet bokmärken per konto.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximalt tillåtet antal bokmärken per konto. (0 för ingen gräns; standard är ingen gräns)",
     "Previews" : "Förhandsvisningar",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "För att visa riktiga skärmdumpar av dina bokmärkta webbplatser kan appen använda tjänster från tredje part för att skapa förhandsvisningar.",
+    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "För att visa riktiga skärmdumpar av dina bokmärkta webbplatser kan appen använda tredjepartstjänster för att generera förhandsvisningar.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Du kan antingen registrera dig gratis på screeenly.com eller sätta upp en egen server.",
     "Screeenly API URL" : "Screeenly API-webbadress",
     "Screeenly API key" : "Screeenly API-nyckel",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "Webshot API URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API nyckel",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "Webshot API URL",
+    "Generic screenshot API" : "Generisk skärmdump API",
+    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Registrera dig hos någon av API-leverantörerna för skärmdumpar och ange API-URL nedan. Använd variabeln {url} som platshållare för webbadressen för skärmdump. API:t måste endast returnera bilden direkt.",
+    "Generic API URL" : "Generisk API URL",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installera Pageres CLI på din server så hittar Bokmärken det. Du kan fortfarande lägga till ytterligare ENV-variabler som ska matas till Pageres, t.ex. som anges i platshållaren:",
+    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installera Pageres CLI av Sindre Sorhus på din server så hittar Bokmärken det. Du kan fortfarande lägga till ytterligare ENV-variabler som ska matas till Pageres, t.ex. som anges i platshållaren:",
     "Pageres ENV variables" : "Pageres ENV-variabler",
     "Failed to save settings" : "Kunde inte spara inställningarna",
     "Failed to load settings" : "Kunde inte läsa in inställningar",
@@ -241,6 +245,7 @@ OC.L10N.register(
     "Failed to rename tag" : "Kunde inte döpa om tagg",
     "Failed to load tags" : "Kunde inte läsa in taggar",
     "Failed to load folders" : "Kunde inte läsa in mappar",
+    "Failed to load deleted folders" : "Kunde inte läsa in borttagna mappar",
     "Failed to load deleted bookmarks" : "Kunde inte läsa in borttagna bokmärken",
     "Failed to delete folder" : "Kunde inte radera mapp",
     "Failed to move folder" : "Det gick inte att flytta mappen",
