@@ -4,17 +4,17 @@ OC.L10N.register(
     "Details" : "Details",
     "Rename" : "Rename",
     "Move" : "Move",
-    "Delete" : "Delete",
     "Select all" : "Select all",
     "New" : "New",
     "New folder" : "New folder",
     "Search" : "Search",
-    "Delete folder" : "Delete folder",
     "Cancel" : "Cancel",
     "Recent" : "Recent",
     "Shared with you" : "Shared with you",
     "Files" : "Files",
+    "Delete" : "Delete",
     "Settings" : "Sozlamalar",
+    "Need help?" : "Need help?",
     "Link" : "Link",
     "Tags" : "Tags",
     "Notes" : "Notes",
