@@ -38,7 +38,6 @@ OC.L10N.register(
     "Create bookmark" : "创建书签",
     "Takes a link and adds it to your collection of bookmarks." : "获取一个链接并将其添加到您的书签中。",
     "Bookmarks Backups" : "书签备份",
-    "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
     "Enter new title" : "输入新标题",
     "Select bookmark" : "选择书签",
     "Details" : "详情",
@@ -173,23 +172,20 @@ OC.L10N.register(
     "Remove share" : "移除共享",
     "Link copied" : "已复制链接",
     "Privacy" : "隐私",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "书签应用将访问您添加的网页以自动获取关于它们的信息。",
     "Enable accessing and collecting information from the web pages you add" : "启用从您添加的网页访问和搜集信息的功能",
     "Performance" : "性能",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在有很多用户的安装中，限制每个账号的书签数量可能是有用的。",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每个账号允许的最大书签数量。（0为无限制；默认为无限制）",
     "Previews" : "预览",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "为了显示你的书签网站的真实截图，书签可以使用第三方服务来生成预览。",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "您既可以在 screeenly.com 免费注册，也可以搭建您自己的服务器。",
     "Screeenly API URL" : "Screenly API 地址",
     "Screeenly API key" : "Screenly API 密钥",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "Webshot API URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API key",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "Webshot API URL",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的服务器上安装 Pageres CLI，书签应用就会找到它。您也可以为 pageres 添加额外的 ENV 变量，如在占位符中所示：",
     "Pageres ENV variables" : "Pageres ENV 变量",
     "Failed to save settings" : "保存设置失败",
     "Failed to load settings" : "加载设置失败",
