@@ -38,10 +38,12 @@ OC.L10N.register(
     "Create bookmark" : "已建立書籤",
     "Takes a link and adds it to your collection of bookmarks." : "將連結添加到您的書籤收藏。",
     "Bookmarks Backups" : "書籤備份",
-    "A Bookmark manager for Nextcloud" : "Nextcloud上的書籤管理員",
-    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- 🔍 Full-text search\n- 📲 Synchronize with all your browsers and devices\n- 👪 Share bookmarks with other users and publicly\n- ☠ Find broken links\n- ⚛ Generate RSS feeds of your collections\n- 📔 Read archived versions of your links in case they are depublished\n- 💬 Create new bookmarks directly from within Nextcloud Talk\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類到資料夾中\n- 🏷 新增標籤與個人筆記\n- 🔍 全文搜尋\n- 📲 與您所有的瀏覽器及裝置同步\n- 👪 與其他用戶分享或是公開分享\n- ☠ 尋找壞掉的連結\n- ⚛ 產生您收藏的 RSS 摘要\n- 📔 若您的連結被取消發佈，您還是可以閱讀它們的封存版本\n- 💬 直接從 Nextcloud Talk 建立新書籤\n- 💼 用於經常造訪與最近新增連結的內建儀表板小工具\n\n系統需求：\n - PHP 擴充套件：\n   - intl: *\n   - mbstring: *\n - 若使用 MySQL，則至少需要 v8.0",
+    "Collect and manage bookmarks, synced with all your devices" : "收集和管理書籤．並與所有裝置同步",
+    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users and via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類整理到資料夾中\n- 🏷 新增標籤及個人筆記\n- ☠ 找出失效連結及重複項目\n- 📲 與所有瀏覽器及裝置同步\n- 📔 儲存連結的已存檔版本,以防連結停止發佈\n- 🔍 對網站內容進行全文搜索\n- 👪 與其他使用者分享書籤,並提供公開連結\n- ⚛ 為您的書籤集合產生 RSS 訂閱源\n- 📈 統計您存取各個連結的頻率\n- 🔒 自動備份您的書籤集合\n- 💼 內建儀表板小組件以顯示常用及最近的連結\n\n技術要求:\n- PHP 擴充套件:\n- intl: *\n- mbstring: *\n- 使用 MySQL 時，需使用至少 v8.0 版本",
     "Enter new title" : "輸入新的標題",
     "Select bookmark" : "選擇書籤",
+    "You have never clicked this link" : "您從未點擊過此連結",
+    "You have clicked this link {count} times" : "您已點擊過此連結 {count} 次",
     "Details" : "細節",
     "Rename" : "重新命名",
     "Copy link" : "複製連結",
@@ -202,23 +204,26 @@ OC.L10N.register(
     "Remove share" : "移除分享",
     "Link copied" : "連結已複製",
     "Privacy" : "私隱",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "書籤將嘗試存取您添加的網頁，以自動添加有關它們的信息。",
+    "The app will try to access web pages that you add to automatically add information about them." : "該應用程式將嘗試存取您新增的網頁以自動新增關於它們的資訊。",
     "Enable accessing and collecting information from the web pages you add" : "從您增加的網頁啟用存取及收集資訊",
     "Performance" : "效能",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在具有大量用戶的安裝中，限制每個帳戶的書籤數量可能很有用。",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每個帳號可以允許的書籤最大數量。（0是無限制; 預設是無限制）",
     "Previews" : "預覽",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "為了顯示您添加了書籤的網站的真實螢幕截圖，Bookmarks 可以使用第三方服務來生成預覽。",
+    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "為了顯示您加入書籤的網站的真實螢幕截圖，該應用程式會使用第三方服務來生成預覽。",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "您可以免費在 screeenly。com 註冊或是設定您自己的伺服器。",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API key",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "Webshot API URL",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "Webshot API URL",
+    "Generic screenshot API" : "一般螢幕截圖 API",
+    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "向任何螢幕截圖 API 提供者註冊，並將 API URL 放在下面。使用變數 {url} 作為螢幕截圖 URL 的佔位字串。 API 必須僅直接傳回影像。",
+    "Generic API URL" : "一般 API URL",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的伺服器上安裝 Pageres CLI，書籤應用程式就會找到它。您仍然可以新增額外的 ENV 變數以提供給 pageres，例如在佔位字串中所示：",
+    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的伺服器上安裝 Sindre Sorhus 開發的 Pageres CLI，書籤應用程式就會找到它。您仍然可以新增額外的 ENV 變數以提供給 pageres，例如在佔位字串中所示：",
     "Pageres ENV variables" : "Pageres ENV 變數",
     "Failed to save settings" : "設定儲存失敗",
     "Failed to load settings" : "載入設定失敗",
@@ -230,6 +235,7 @@ OC.L10N.register(
     "Save" : "儲存",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "默認情況下，網絡存取處於停用狀態。轉到書籤應用程式的管理員設置，以啟用獲取預覽和網站圖標的功能。",
     "What's new?" : "有什麼新鮮事？",
+    "Leave a rating on the Nextcloud App Store" : "在 Nextcloud App Store 留下評分",
     "What" : "甚麼",
     "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
     "Failed to count archived bookmarks" : "無法點算已封存的書籤",
@@ -244,6 +250,7 @@ OC.L10N.register(
     "Failed to rename tag" : "重新命名標籤失敗",
     "Failed to load tags" : "載入標記失敗",
     "Failed to load folders" : "載入資料夾失敗",
+    "Failed to load deleted folders" : "載入已刪除資料夾失敗",
     "Failed to load deleted bookmarks" : "無法加載已刪除書籤",
     "Failed to delete folder" : "刪除資料夾失敗",
     "Failed to move folder" : "無法移動資料夾",
