@@ -276,4 +276,12 @@ class InternalBookmarkController extends ApiController {
 	public function getDeletedBookmarks(): DataResponse {
 		return $this->publicController->getDeletedBookmarks();
 	}
+
+	public function countAllClicks(): DataResponse {
+		return $this->publicController->countAllClicks();
+	}
+
+	public function countWithClicks(): DataResponse {
+		return $this->publicController->countWithClicks();
+	}
 }
