@@ -25,48 +25,12 @@ use OCA\Bookmarks\Exception\UnsupportedOperation;
 use OCA\Bookmarks\Exception\UserLimitExceededError;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\MultipleObjectsReturnedException;
+use OCP\DB\Exception;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IGroupManager;
-use OCP\IL10N;
 use OCP\Share\IShare;
 
 class FolderService {
-	/**
-	 * @var FolderMapper
-	 */
-	private $folderMapper;
-	/**
-	 * @var TreeMapper
-	 */
-	private $treeMapper;
-	/**
-	 * @var ShareMapper
-	 */
-	private $shareMapper;
-	/**
-	 * @var SharedFolderMapper
-	 */
-	private $sharedFolderMapper;
-	/**
-	 * @var PublicFolderMapper
-	 */
-	private $publicFolderMapper;
-	/**
-	 * @var IGroupManager
-	 */
-	private $groupManager;
-	/**
-	 * @var HtmlImporter
-	 */
-	private $htmlImporter;
-	/**
-	 * @var IL10N
-	 */
-	private $l10n;
-	/**
-	 * @var IEventDispatcher
-	 */
-	private $eventDispatcher;
 
 	/**
 	 * FolderService constructor.
@@ -78,19 +42,19 @@ class FolderService {
 	 * @param PublicFolderMapper $publicFolderMapper
 	 * @param IGroupManager $groupManager
 	 * @param HtmlImporter $htmlImporter
-	 * @param IL10N $l10n
 	 * @param IEventDispatcher $eventDispatcher
 	 */
-	public function __construct(FolderMapper $folderMapper, TreeMapper $treeMapper, ShareMapper $shareMapper, SharedFolderMapper $sharedFolderMapper, PublicFolderMapper $publicFolderMapper, IGroupManager $groupManager, HtmlImporter $htmlImporter, IL10N $l10n, IEventDispatcher $eventDispatcher) {
-		$this->folderMapper = $folderMapper;
-		$this->treeMapper = $treeMapper;
-		$this->shareMapper = $shareMapper;
-		$this->sharedFolderMapper = $sharedFolderMapper;
-		$this->publicFolderMapper = $publicFolderMapper;
-		$this->groupManager = $groupManager;
-		$this->htmlImporter = $htmlImporter;
-		$this->l10n = $l10n;
-		$this->eventDispatcher = $eventDispatcher;
+	public function __construct(
+		private FolderMapper $folderMapper,
+		private TreeMapper $treeMapper,
+		private ShareMapper $shareMapper,
+		private SharedFolderMapper $sharedFolderMapper,
+		private PublicFolderMapper $publicFolderMapper,
+		private IGroupManager $groupManager,
+		private HtmlImporter $htmlImporter,
+		private IEventDispatcher $eventDispatcher,
+		private CirclesService $circlesService,
+	) {
 	}
 
 	public function getRootFolder(string $userId) : Folder {
@@ -171,38 +135,45 @@ class FolderService {
 	}
 
 	/**
-	 * @param $userId
-	 * @param $folderId
+	 * @param string $userId
+	 * @param int $folderId
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnsupportedOperation
+	 * @throws Exception
 	 */
-	public function deleteSharedFolderOrFolder($userId, $folderId): void {
-		/**
-		 * @var $folder Folder
-		 */
+	public function deleteSharedFolderOrFolder(string $userId, int $folderId, bool $hardDelete): void {
 		$folder = $this->folderMapper->find($folderId);
 
 		if ($userId === null || $userId === $folder->getUserId()) {
-			$this->treeMapper->deleteEntry(TreeMapper::TYPE_FOLDER, $folder->getId());
+			if ($hardDelete) {
+				$this->treeMapper->deleteEntry(TreeMapper::TYPE_FOLDER, $folder->getId());
+			} else {
+				$this->treeMapper->softDeleteEntry(TreeMapper::TYPE_FOLDER, $folder->getId());
+			}
 			return;
 		}
 
 		try {
 			// folder is shared folder
-			/**
-			 * @var $sharedFolder SharedFolder
-			 */
 			$sharedFolder = $this->sharedFolderMapper->findByFolderAndUser($folder->getId(), $userId);
-			$this->treeMapper->deleteEntry(TreeMapper::TYPE_SHARE, $sharedFolder->getId());
+			if ($hardDelete) {
+				$this->treeMapper->deleteEntry(TreeMapper::TYPE_SHARE, $sharedFolder->getId());
+			} else {
+				$this->treeMapper->softDeleteEntry(TreeMapper::TYPE_SHARE, $sharedFolder->getId());
+			}
 			return;
 		} catch (DoesNotExistException $e) {
 			// noop
 		}
 
 		// folder is subfolder of share
-		$this->treeMapper->deleteEntry(TreeMapper::TYPE_FOLDER, $folder->getId());
-		$this->folderMapper->delete($folder);
+		if ($hardDelete) {
+			$this->treeMapper->deleteEntry(TreeMapper::TYPE_FOLDER, $folder->getId());
+			$this->folderMapper->delete($folder);
+		} else {
+			$this->treeMapper->softDeleteEntry(TreeMapper::TYPE_FOLDER, $folder->getId());
+		}
 	}
 
 	/**
@@ -215,6 +186,31 @@ class FolderService {
 		$this->treeMapper->deleteShare($shareId);
 	}
 
+	/**
+	 * @throws UnsupportedOperation
+	 * @throws MultipleObjectsReturnedException
+	 * @throws DoesNotExistException|Exception
+	 */
+	public function undelete(?string $userId, int $folderId): void {
+		$folder = $this->folderMapper->find($folderId);
+		if ($userId === null || $userId === $folder->getUserId()) {
+			$this->treeMapper->softUndeleteEntry(TreeMapper::TYPE_FOLDER, $folderId);
+			return;
+		}
+
+		try {
+			// folder is shared folder
+			$sharedFolder = $this->sharedFolderMapper->findByFolderAndUser($folder->getId(), $userId);
+			$this->treeMapper->softUndeleteEntry(TreeMapper::TYPE_SHARE, $sharedFolder->getId());
+			return;
+		} catch (DoesNotExistException $e) {
+			// noop
+		}
+
+		// folder is subfolder of share
+		$this->treeMapper->softUndeleteEntry(TreeMapper::TYPE_FOLDER, $folder->getId());
+	}
+
 	/**
 	 * @param string $userId
 	 * @param int $folderId
@@ -306,8 +302,9 @@ class FolderService {
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnsupportedOperation
+	 * @throws Exception
 	 */
-	public function createShare($folderId, $participant, int $type, $canWrite = false, $canShare = false): Share {
+	public function createShare($folderId, $participant, int $type, bool $canWrite = false, bool $canShare = false): Share {
 		/**
 		 * @var $folder Folder
 		 */
@@ -331,15 +328,43 @@ class FolderService {
 			}
 			$this->shareMapper->insert($share);
 			$this->addSharedFolder($share, $folder, $participant);
-		} elseif ($type === IShare::TYPE_GROUP) {
-			$group = $this->groupManager->get($participant);
-			if ($group === null) {
-				throw new DoesNotExistException('Group does not exist');
+		} else {
+			$this->addSharedFolderForParticipant($share, $folder, $type, $participant);
+		}
+
+
+		return $share;
+	}
+
+	/**
+	 * @throws MultipleObjectsReturnedException
+	 * @throws UnsupportedOperation
+	 * @throws DoesNotExistException
+	 * @throws Exception
+	 */
+	public function addSharedFolderForParticipant(Share $share, Folder $folder, int $type, string $participant): void {
+		if ($type === IShare::TYPE_CIRCLE) {
+			$circle = $this->circlesService->getCircle($participant);
+			if ($circle === null) {
+				throw new DoesNotExistException('Circle does not exist');
 			}
 			$this->shareMapper->insert($share);
+
+			$members = $circle->getMembers();
+			foreach ($members as $member) {
+				$this->addSharedFolderForParticipant($share, $folder, $member->getUserType(), $member->getUserId());
+			}
+		}
+		if ($type === IShare::TYPE_GROUP) {
+			$group = $this->groupManager->get($participant);
+			if ($group === null) {
+				return;
+			}
+			$this->shareMapper->insert($share);
+
 			$users = $group->getUsers();
 			foreach ($users as $user) {
-				// If I'm part of the group, don't add it twice
+				// If owner is part of the group, don't add it twice
 				if ($user->getUID() === $folder->getUserId()) {
 					continue;
 				}
@@ -355,11 +380,26 @@ class FolderService {
 
 				$this->addSharedFolder($share, $folder, $user->getUID());
 			}
-		} else {
-			throw new UnsupportedOperation('Only users and groups are allowed as participants');
 		}
+		if ($type === IShare::TYPE_USER) {
+			// User is already owner of folder
+			if ($participant === $folder->getUserId()) {
+				return;
+			}
+			// If this folder is already shared with the user, don't add it twice.
+			if ($this->treeMapper->isFolderSharedWithUser($folder->getId(), $participant)) {
+				return;
+			}
 
-		return $share;
+			// If this folder already contains a share from this user, don't share it back. Would cause a loop.
+			if ($this->treeMapper->containsSharedFolderFromUser($folder, $participant)) {
+				return;
+			}
+
+			$this->shareMapper->insert($share);
+
+			$this->addSharedFolder($share, $folder, $participant);
+		}
 	}
 
 	/**
