@@ -21,6 +21,8 @@ export const actions = {
 	COUNT_UNAVAILABLE: 'COUNT_UNAVAILABLE',
 	COUNT_ARCHIVED: 'COUNT_ARCHIVED',
 	COUNT_DUPLICATED: 'COUNT_DUPLICATED',
+	COUNT_ALL_CLICKS: 'COUNT_ALL_CLICKS',
+	COUNT_WITH_CLICKS: 'COUNT_WITH_CLICKS',
 
 	CREATE_BOOKMARK: 'CREATE_BOOKMARK',
 	FIND_BOOKMARK: 'FIND_BOOKMARK',
@@ -102,13 +104,13 @@ export default {
 				return commit(mutations.SET_UNAVAILABLE_COUNT, count)
 			} catch (e) {
 				console.warn(
-					'Could not load initial unavailable bookmarks count state, continuing with HTTP request'
+					'Could not load initial unavailable bookmarks count state, continuing with HTTP request',
 				)
 			}
 		}
 		try {
 			const response = await axios.get(
-				url(state, '/bookmark/unavailable')
+				url(state, '/bookmark/unavailable'),
 			)
 			const {
 				data: { item: count, data, status },
@@ -123,8 +125,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to count unavailable bookmarks'
-				)
+					'Failed to count unavailable bookmarks',
+				),
 			)
 			throw err
 		}
@@ -136,7 +138,7 @@ export default {
 				return commit(mutations.SET_ARCHIVED_COUNT, count)
 			} catch (e) {
 				console.warn(
-					'Could not load initial archived bookmarks count state, continuing with HTTP request'
+					'Could not load initial archived bookmarks count state, continuing with HTTP request',
 				)
 			}
 		}
@@ -155,8 +157,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to count archived bookmarks'
-				)
+					'Failed to count archived bookmarks',
+				),
 			)
 			throw err
 		}
@@ -168,7 +170,7 @@ export default {
 				return commit(mutations.SET_DUPLICATED_COUNT, count)
 			} catch (e) {
 				console.warn(
-					'Could not load initial duplicated bookmarks count state, continuing with HTTP request'
+					'Could not load initial duplicated bookmarks count state, continuing with HTTP request',
 				)
 			}
 		}
@@ -187,12 +189,32 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to count duplicated bookmarks'
-				)
+					'Failed to count duplicated bookmarks',
+				),
 			)
 			throw err
 		}
 	},
+	async [actions.COUNT_ALL_CLICKS]({ commit, dispatch, state }) {
+		try {
+			const count = loadState('bookmarks', 'allClicksCount')
+			return commit(mutations.SET_ALL_CLICKS_COUNT, count)
+		} catch (e) {
+			console.warn(
+				'Could not load initial all clicks count state',
+			)
+		}
+	},
+	async [actions.COUNT_WITH_CLICKS]({ commit, dispatch, state }) {
+		try {
+			const count = loadState('bookmarks', 'withClicksCount')
+			return commit(mutations.SET_WITH_CLICKS_COUNT, count)
+		} catch (e) {
+			console.warn(
+				'Could not load initial bookmarks with clicks count state',
+			)
+		}
+	},
 	async [actions.COUNT_BOOKMARKS]({ commit, dispatch, state }, folderId) {
 		if (String(folderId) === String(-1) && typeof state.countsByFolder[folderId] === 'undefined') {
 			try {
@@ -201,13 +223,13 @@ export default {
 			} catch (e) {
 				console.warn(e)
 				console.warn(
-					'Could not load initial bookmarks count state, continuing with HTTP request'
+					'Could not load initial bookmarks count state, continuing with HTTP request',
 				)
 			}
 		}
 		try {
 			const response = await axios.get(
-				url(state, `/folder/${folderId}/count`)
+				url(state, `/folder/${folderId}/count`),
 			)
 			const {
 				data: { item: count, data, status },
@@ -220,7 +242,7 @@ export default {
 			console.error(err)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to count bookmarks')
+				AppGlobal.methods.t('bookmarks', 'Failed to count bookmarks'),
 			)
 			throw err
 		}
@@ -240,7 +262,7 @@ export default {
 			console.error(err)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to load bookmark')
+				AppGlobal.methods.t('bookmarks', 'Failed to load bookmark'),
 			)
 			throw err
 		}
@@ -268,8 +290,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to find existing bookmark'
-				)
+					'Failed to find existing bookmark',
+				),
 			)
 			throw err
 		}
@@ -357,7 +379,7 @@ export default {
 			commit(mutations.REMOVE_BOOKMARK, prelimBookmark.id)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to create bookmark')
+				AppGlobal.methods.t('bookmarks', 'Failed to create bookmark'),
 			)
 			throw err
 		}
@@ -367,7 +389,7 @@ export default {
 		try {
 			const response = await axios.put(
 				url(state, `/bookmark/${id}`),
-				this.getters.getBookmark(id)
+				this.getters.getBookmark(id),
 			)
 			const {
 				data: { status },
@@ -381,14 +403,14 @@ export default {
 			commit(mutations.FETCH_END, 'saveBookmark')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to save bookmark')
+				AppGlobal.methods.t('bookmarks', 'Failed to save bookmark'),
 			)
 			throw err
 		}
 	},
 	async [actions.MOVE_BOOKMARK](
 		{ commit, dispatch, state },
-		{ bookmark, oldFolder, newFolder }
+		{ bookmark, oldFolder, newFolder },
 	) {
 		if (Number(oldFolder) === Number(newFolder)) {
 			return
@@ -396,14 +418,14 @@ export default {
 		commit(mutations.FETCH_START, { type: 'moveBookmark' })
 		try {
 			const response = await axios.post(
-				url(state, `/folder/${newFolder}/bookmarks/${bookmark}`)
+				url(state, `/folder/${newFolder}/bookmarks/${bookmark}`),
 			)
 			if (response.data.status !== 'success') {
 				throw new Error(response.data)
 			}
 			if (oldFolder) {
 				const response2 = await axios.delete(
-					url(state, `/folder/${oldFolder}/bookmarks/${bookmark}`)
+					url(state, `/folder/${oldFolder}/bookmarks/${bookmark}`),
 				)
 				if (response2.data.status !== 'success') {
 					throw new Error(response2.data)
@@ -417,14 +439,14 @@ export default {
 			commit(mutations.FETCH_END, 'moveBookmark')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to move bookmark')
+				AppGlobal.methods.t('bookmarks', 'Failed to move bookmark'),
 			)
 			throw err
 		}
 	},
 	async [actions.COPY_BOOKMARK](
 		{ commit, dispatch, state },
-		{ bookmark, oldFolder, newFolder }
+		{ bookmark, oldFolder, newFolder },
 	) {
 		if (Number(oldFolder) === Number(newFolder)) {
 			return
@@ -432,7 +454,7 @@ export default {
 		commit(mutations.FETCH_START, { type: 'copyBookmark' })
 		try {
 			const response = await axios.post(
-				url(state, `/folder/${newFolder}/bookmarks/${bookmark}`)
+				url(state, `/folder/${newFolder}/bookmarks/${bookmark}`),
 			)
 			if (response.data.status !== 'success') {
 				throw new Error(response.data)
@@ -444,12 +466,13 @@ export default {
 			commit(mutations.FETCH_END, 'copyBookmark')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to copy bookmark')
+				AppGlobal.methods.t('bookmarks', 'Failed to copy bookmark'),
 			)
 			throw err
 		}
 	},
 	async [actions.CLICK_BOOKMARK]({ commit, dispatch, state }, bookmark) {
+		commit(mutations.CLICK_BOOKMARK, bookmark)
 		commit(mutations.FETCH_START, { type: 'clickBookmark' })
 		try {
 			const response = await axios.post(url(state, '/bookmark/click'), {
@@ -470,12 +493,12 @@ export default {
 	},
 	async [actions.DELETE_BOOKMARK](
 		{ commit, dispatch, state },
-		{ id, folder, avoidReload, hard }
+		{ id, folder, avoidReload, hard },
 	) {
 		if (folder) {
 			try {
 				const response = await axios.delete(
-					url(state, `/folder/${folder}/bookmarks/${id}` + (hard ? '?hardDelete' : ''))
+					url(state, `/folder/${folder}/bookmarks/${id}` + (hard ? '?hardDelete=true' : '')),
 				)
 				if (response.data.status !== 'success') {
 					throw new Error(response.data)
@@ -491,8 +514,8 @@ export default {
 					mutations.SET_ERROR,
 					AppGlobal.methods.t(
 						'bookmarks',
-						'Failed to delete bookmark'
-					)
+						'Failed to delete bookmark',
+					),
 				)
 				throw err
 			}
@@ -510,18 +533,18 @@ export default {
 			console.error(err)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to delete bookmark')
+				AppGlobal.methods.t('bookmarks', 'Failed to delete bookmark'),
 			)
 			throw err
 		}
 	},
 	async [actions.UNDELETE_BOOKMARK](
 		{ commit, dispatch, state, getters },
-		{ id, folder, avoidReload }
+		{ id, folder, avoidReload },
 	) {
 		try {
 			const response = await axios.post(
-				url(state, `/folder/${folder}/bookmarks/${id}/undelete`)
+				url(state, `/folder/${folder}/bookmarks/${id}/undelete`),
 			)
 			if (response.data.status !== 'success') {
 				throw new Error(response.data)
@@ -541,15 +564,15 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to restore bookmark'
-				)
+					'Failed to restore bookmark',
+				),
 			)
 			throw err
 		}
 	},
 	async [actions.IMPORT_BOOKMARKS](
 		{ commit, dispatch, state },
-		{ file, folder }
+		{ file, folder },
 	) {
 		commit(mutations.FETCH_START, { type: 'importBookmarks' })
 		const data = new FormData()
@@ -557,7 +580,7 @@ export default {
 		try {
 			const response = await axios.post(
 				url(state, `/folder/${folder || -1}/import`),
-				data
+				data,
 			)
 			if (!response.data || response.data.status !== 'success') {
 				if (response.status === 413) {
@@ -567,7 +590,7 @@ export default {
 				throw new Error(
 					Array.isArray(response.data.data)
 						? response.data.data.join('. ')
-						: response.data.data
+						: response.data.data,
 				)
 			}
 			await dispatch(actions.COUNT_BOOKMARKS, -1)
@@ -576,7 +599,7 @@ export default {
 			commit(mutations.FETCH_END, 'importBookmarks')
 			return commit(
 				mutations.SET_NOTIFICATION,
-				AppGlobal.methods.t('bookmarks', 'Import successful')
+				AppGlobal.methods.t('bookmarks', 'Import successful'),
 			)
 		} catch (err) {
 			console.error(err)
@@ -606,7 +629,7 @@ export default {
 				commit(mutations.FETCH_END, 'deleteBookmarks')
 				commit(
 					mutations.SET_ERROR,
-					AppGlobal.methods.t('bookmarks', err.message)
+					AppGlobal.methods.t('bookmarks', err.message),
 				)
 				throw err
 			})
@@ -614,7 +637,7 @@ export default {
 
 	async [actions.RENAME_TAG](
 		{ commit, dispatch, state },
-		{ oldName, newName }
+		{ oldName, newName },
 	) {
 		commit(mutations.FETCH_START, { type: 'tag' })
 		try {
@@ -635,7 +658,7 @@ export default {
 			commit(mutations.FETCH_END, 'tag')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to rename tag')
+				AppGlobal.methods.t('bookmarks', 'Failed to rename tag'),
 			)
 			throw err
 		}
@@ -648,7 +671,7 @@ export default {
 			} catch (e) {
 				console.warn(e)
 				console.warn(
-					'Could not load initial bookmarks count state, continuing with HTTP request'
+					'Could not load initial bookmarks count state, continuing with HTTP request',
 				)
 			}
 		}
@@ -665,7 +688,7 @@ export default {
 				commit(mutations.FETCH_END, 'tags')
 				commit(
 					mutations.SET_ERROR,
-					AppGlobal.methods.t('bookmarks', 'Failed to load tags')
+					AppGlobal.methods.t('bookmarks', 'Failed to load tags'),
 				)
 				throw err
 			})
@@ -689,8 +712,8 @@ export default {
 					mutations.SET_ERROR,
 					AppGlobal.methods.t(
 						'bookmarks',
-						'Failed to delete bookmark'
-					)
+						'Failed to delete bookmark',
+					),
 				)
 				throw err
 			})
@@ -703,7 +726,7 @@ export default {
 				return commit(mutations.SET_FOLDERS, folders)
 			} catch (e) {
 				console.warn(
-					'Could not load initial folder state, continuing with HTTP request'
+					'Could not load initial folder state, continuing with HTTP request',
 				)
 			}
 		}
@@ -731,7 +754,7 @@ export default {
 			commit(mutations.FETCH_END, 'folders')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to load folders')
+				AppGlobal.methods.t('bookmarks', 'Failed to load folders'),
 			)
 			throw err
 		}
@@ -744,7 +767,7 @@ export default {
 				return commit(mutations.SET_DELETED_FOLDERS, count)
 			} catch (e) {
 				console.warn(
-					'Could not load initial deleted folders state, continuing with HTTP request'
+					'Could not load initial deleted folders state, continuing with HTTP request',
 				)
 			}
 		}
@@ -772,7 +795,7 @@ export default {
 			commit(mutations.FETCH_END, 'folders')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to load folders')
+				AppGlobal.methods.t('bookmarks', 'Failed to load deleted folders'),
 			)
 			throw err
 		}
@@ -807,7 +830,7 @@ export default {
 			commit(mutations.FETCH_END, 'bookmarks')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to load deleted bookmarks')
+				AppGlobal.methods.t('bookmarks', 'Failed to load deleted bookmarks'),
 			)
 			throw err
 		}
@@ -815,10 +838,10 @@ export default {
 
 	async [actions.DELETE_FOLDER](
 		{ commit, dispatch, state },
-		{ id, avoidReload, hard }
+		{ id, avoidReload, hard },
 	) {
 		try {
-			const response = await axios.delete(url(state, `/folder/${id}` + (hard ? '?hardDelete' : '')))
+			const response = await axios.delete(url(state, `/folder/${id}` + (hard ? '?hardDelete=true' : '')))
 			const {
 				data: { status },
 			} = response
@@ -829,22 +852,23 @@ export default {
 			if (!avoidReload) {
 				await dispatch(
 					actions.LOAD_FOLDER_CHILDREN_ORDER,
-					parentFolder
+					parentFolder,
 				)
 				await dispatch(actions.LOAD_FOLDERS)
+				await dispatch(actions.LOAD_DELETED_FOLDERS)
 			}
 		} catch (err) {
 			console.error(err)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to delete folder')
+				AppGlobal.methods.t('bookmarks', 'Failed to delete folder'),
 			)
 			throw err
 		}
 	},
 	async [actions.MOVE_FOLDER](
 		{ commit, dispatch, state },
-		{ folderId, targetFolderId }
+		{ folderId, targetFolderId },
 	) {
 		try {
 			const folder = this.getters.getFolder(folderId)[0]
@@ -855,7 +879,7 @@ export default {
 				await dispatch(actions.SAVE_FOLDER, folder.id) // reloads children order for new parent
 				dispatch(
 					actions.LOAD_FOLDER_CHILDREN_ORDER,
-					oldParent
+					oldParent,
 				)
 			} catch (err) {
 				commit(mutations.MOVE_FOLDER, { folder: folder.id, target: oldParent })
@@ -866,14 +890,14 @@ export default {
 			console.error(err)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to move folder')
+				AppGlobal.methods.t('bookmarks', 'Failed to move folder'),
 			)
 			throw err
 		}
 	},
 	async [actions.UNDELETE_FOLDER](
 		{ commit, dispatch, state },
-		{ id, avoidReload }
+		{ id, avoidReload },
 	) {
 		try {
 			const parentFolderId = this.getters.getFolder(id)[0].parent_folder
@@ -891,7 +915,7 @@ export default {
 			if (!avoidReload) {
 				await dispatch(
 					actions.LOAD_FOLDER_CHILDREN_ORDER,
-					parentFolderId
+					parentFolderId,
 				)
 				await dispatch(actions.LOAD_FOLDERS)
 				await dispatch(actions.LOAD_DELETED_FOLDERS)
@@ -900,14 +924,14 @@ export default {
 			console.error(err)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to restore folder')
+				AppGlobal.methods.t('bookmarks', 'Failed to restore folder'),
 			)
 			throw err
 		}
 	},
 	async [actions.CREATE_FOLDER](
 		{ commit, dispatch, state },
-		{ parentFolder, title }
+		{ parentFolder, title },
 	) {
 		try {
 			const response = await axios.post(url(state, '/folder'), {
@@ -923,14 +947,14 @@ export default {
 			commit(mutations.DISPLAY_NEW_FOLDER, false)
 			await dispatch(
 				actions.LOAD_FOLDER_CHILDREN_ORDER,
-				parentFolder || -1
+				parentFolder || -1,
 			)
 			await dispatch(actions.LOAD_FOLDERS, /* force: */ true)
 		} catch (err) {
 			console.error(err)
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to create folder')
+				AppGlobal.methods.t('bookmarks', 'Failed to create folder'),
 			)
 			throw err
 		}
@@ -952,7 +976,7 @@ export default {
 			}
 			await dispatch(
 				actions.LOAD_FOLDER_CHILDREN_ORDER,
-				folder.parent_folder
+				folder.parent_folder,
 			)
 			commit(mutations.FETCH_END, 'saveFolder')
 		} catch (err) {
@@ -960,19 +984,19 @@ export default {
 			commit(mutations.FETCH_END, 'saveFolder')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.methods.t('bookmarks', 'Failed to create folder')
+				AppGlobal.methods.t('bookmarks', 'Failed to create folder'),
 			)
 			throw err
 		}
 	},
 	async [actions.LOAD_FOLDER_CHILDREN_ORDER](
 		{ commit, dispatch, state },
-		id
+		id,
 	) {
 		commit(mutations.FETCH_START, { type: 'childrenOrder' })
 		try {
 			const response = await axios.get(
-				url(state, `/folder/${id}/childorder`)
+				url(state, `/folder/${id}/childorder`),
 			)
 			const {
 				data: { status },
@@ -992,8 +1016,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to load children order'
-				)
+					'Failed to load children order',
+				),
 			)
 			throw err
 		}
@@ -1013,7 +1037,7 @@ export default {
 				async folder => {
 					await dispatch(actions.MOVE_FOLDER, { folderId: folder.id, targetFolderId: folderId })
 				},
-				10
+				10,
 			)
 			await Parallel.each(
 				state.selection.bookmarks,
@@ -1026,7 +1050,7 @@ export default {
 						bookmark: bookmark.id,
 					})
 				},
-				10
+				10,
 			)
 
 			// Because we're possibly moving across share boundaries we need to recount
@@ -1041,8 +1065,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to move parts of selection'
-				)
+					'Failed to move parts of selection',
+				),
 			)
 			throw err
 		}
@@ -1057,7 +1081,7 @@ export default {
 						throw new Error('Cannot copy folders')
 					}
 				},
-				10
+				10,
 			)
 			await Promise.all([
 				dispatch(actions.LOAD_FOLDERS),
@@ -1069,7 +1093,7 @@ export default {
 							bookmark: bookmark.id,
 						})
 					},
-					10
+					10,
 				),
 			])
 
@@ -1081,8 +1105,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to copy parts of selection'
-				)
+					'Failed to copy parts of selection',
+				),
 			)
 			throw err
 		}
@@ -1097,7 +1121,7 @@ export default {
 						id: folder.id,
 						avoidReload: true,
 					}),
-				10
+				10,
 			)
 			await Parallel.each(
 				state.selection.bookmarks,
@@ -1119,7 +1143,7 @@ export default {
 						}))
 					}
 				},
-				10
+				10,
 			)
 			dispatch(actions.RELOAD_VIEW)
 			commit(mutations.FETCH_END, 'deleteSelection')
@@ -1130,8 +1154,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to delete parts of selection'
-				)
+					'Failed to delete parts of selection',
+				),
 			)
 			throw err
 		}
@@ -1150,7 +1174,7 @@ export default {
 						return dispatch(actions.SAVE_BOOKMARK, bookmark.id)
 					}
 				},
-				10
+				10,
 			)
 			await dispatch(actions.LOAD_TAGS)
 			commit(mutations.FETCH_END, 'tagSelection')
@@ -1161,8 +1185,8 @@ export default {
 				mutations.SET_ERROR,
 				AppGlobal.methods.t(
 					'bookmarks',
-					'Failed to tag parts of selection'
-				)
+					'Failed to tag parts of selection',
+				),
 			)
 			throw err
 		}
@@ -1264,7 +1288,7 @@ export default {
 				commit(mutations.FETCH_END, 'bookmarks')
 				commit(
 					mutations.SET_ERROR,
-					AppGlobal.t('bookmarks', 'Failed to fetch bookmarks.')
+					AppGlobal.t('bookmarks', 'Failed to fetch bookmarks.'),
 				)
 				throw err
 			})
@@ -1301,7 +1325,7 @@ export default {
 			commit(mutations.FETCH_END, 'bookmarks')
 			commit(
 				mutations.SET_ERROR,
-				AppGlobal.t('bookmarks', 'Failed to fetch bookmarks.')
+				AppGlobal.t('bookmarks', 'Failed to fetch bookmarks.'),
 			)
 			throw err
 		}
@@ -1326,7 +1350,7 @@ export default {
 				console.error(err)
 				commit(
 					mutations.SET_ERROR,
-					AppGlobal.methods.t('bookmarks', 'Failed to store setting')
+					AppGlobal.methods.t('bookmarks', 'Failed to store setting'),
 				)
 				throw err
 			})
@@ -1355,8 +1379,8 @@ export default {
 					AppGlobal.methods.t(
 						'bookmarks',
 						'Failed to load setting {key}',
-						{ key }
-					)
+						{ key },
+					),
 				)
 				throw err
 			})
@@ -1442,7 +1466,7 @@ export default {
 	},
 	[actions.CREATE_SHARE](
 		{ commit, dispatch, state },
-		{ folderId, type, participant }
+		{ folderId, type, participant },
 	) {
 		return axios
 			.post(url(state, `/folder/${folderId}/shares`), {
@@ -1464,15 +1488,15 @@ export default {
 					AppGlobal.methods.t(
 						'bookmarks',
 						'Failed to create share for folder {folderId}',
-						{ folderId }
-					)
+						{ folderId },
+					),
 				)
 				throw err
 			})
 	},
 	[actions.EDIT_SHARE](
 		{ commit, dispatch, state },
-		{ shareId, canWrite, canShare }
+		{ shareId, canWrite, canShare },
 	) {
 		return axios
 			.put(url(state, `/share/${shareId}`), {
@@ -1493,8 +1517,8 @@ export default {
 					AppGlobal.methods.t(
 						'bookmarks',
 						'Failed to update share {shareId}',
-						{ shareId }
-					)
+						{ shareId },
+					),
 				)
 				throw err
 			})
@@ -1516,8 +1540,8 @@ export default {
 					AppGlobal.methods.t(
 						'bookmarks',
 						'Failed to delete share {shareId}',
-						{ shareId }
-					)
+						{ shareId },
+					),
 				)
 				throw err
 			})
@@ -1562,8 +1586,8 @@ export default {
 					AppGlobal.methods.t(
 						'bookmarks',
 						'Failed to create public link for folder {folderId}',
-						{ folderId }
-					)
+						{ folderId },
+					),
 				)
 				throw err
 			})
@@ -1585,8 +1609,8 @@ export default {
 					AppGlobal.methods.t(
 						'bookmarks',
 						'Failed to delete public link for folder {folderId}',
-						{ folderId }
-					)
+						{ folderId },
+					),
 				)
 				throw err
 			})
